@@ -38,7 +38,6 @@ except ImportError:
         out,err = p.communicate()
         return out
 
-from zmq.eventloop import ioloop
 
 from traitlets.config.application import Application
 from traitlets.config.configurable import LoggingConfigurable
@@ -51,8 +50,8 @@ from IPython.utils.path import get_home_dir, ensure_dir_exists
 from IPython.utils.process import find_cmd, FindCmdError
 from ipython_genutils.py3compat import iteritems, itervalues
 
+from ..util import ioloop
 from .win32support import forward_read_events
-
 from .winhpcjob import IPControllerTask, IPEngineTask, IPControllerJob, IPEngineSetJob
 
 WINDOWS = os.name == 'nt'
@@ -300,23 +299,23 @@ class LocalProcessLauncher(BaseLauncher):
 
     def handle_stdout(self, fd, events):
         if WINDOWS:
-            line = self.stdout.recv()
+            line = self.stdout.recv().decode('utf8', 'replace')
         else:
-            line = self.process.stdout.readline()
+            line = self.process.stdout.readline().decode('utf8', 'replace')
         # a stopped process will be readable but return empty strings
         if line:
-            self.log.debug(line[:-1])
+            self.log.debug(line.rstrip())
         else:
             self.poll()
 
     def handle_stderr(self, fd, events):
         if WINDOWS:
-            line = self.stderr.recv()
+            line = self.stderr.recv().decode('utf8', 'replace')
         else:
-            line = self.process.stderr.readline()
+            line = self.process.stderr.readline().decode('utf8', 'replace')
         # a stopped process will be readable but return empty strings
         if line:
-            self.log.debug(line[:-1])
+            self.log.debug(line.rstrip())
         else:
             self.poll()
 
