@@ -5,15 +5,17 @@
 
 from __future__ import division
 
+import socket
 from concurrent.futures import Future
 from datetime import datetime
 import os
 import sys
 from threading import Thread
 import time
+import mock
 
 import pytest
-from tornado.concurrent import Future as TornadoFuture
+import tornado
 
 from IPython import get_ipython
 from ipyparallel.client import client as clientmod
@@ -24,19 +26,20 @@ from .clienttest import ClusterTestCase, wait, add_engines, skip_without
 
 @pytest.mark.usefixtures('ipython')
 class TestClient(ClusterTestCase):
-    
+
     engine_count = 4
-    
+
     def test_ids(self):
         n = len(self.client.ids)
         self.add_engines(2)
         self.assertEqual(len(self.client.ids), n+2)
-    
+
+
     def test_iter(self):
         self.minimum_engines(4)
         engine_ids = [ view.targets for view in self.client ]
         self.assertEqual(engine_ids, self.client.ids)
-    
+
     def test_view_indexing(self):
         """test index access for views"""
         self.minimum_engines(4)
@@ -64,7 +67,7 @@ class TestClient(ClusterTestCase):
         self.assertTrue(isinstance(v, DirectView))
         self.assertEqual(v.targets, targets[-1])
         self.assertRaises(TypeError, lambda : self.client[None])
-    
+
     def test_lbview_targets(self):
         """test load_balanced_view targets"""
         v = self.client.load_balanced_view()
@@ -73,7 +76,7 @@ class TestClient(ClusterTestCase):
         self.assertEqual(v.targets, [self.client.ids[-1]])
         v = self.client.load_balanced_view('all')
         self.assertEqual(v.targets, None)
-    
+
     def test_dview_targets(self):
         """test direct_view targets"""
         v = self.client.direct_view()
@@ -82,25 +85,25 @@ class TestClient(ClusterTestCase):
         self.assertEqual(v.targets, 'all')
         v = self.client.direct_view(-1)
         self.assertEqual(v.targets, self.client.ids[-1])
-    
+
     def test_lazy_all_targets(self):
         """test lazy evaluation of rc.direct_view('all')"""
         v = self.client.direct_view()
         self.assertEqual(v.targets, 'all')
-        
+
         def double(x):
             return x*2
         seq = list(range(100))
         ref = [ double(x) for x in seq ]
-        
+
         # add some engines, which should be used
         self.add_engines(1)
         n1 = len(self.client.ids)
-        
+
         # simple apply
         r = v.apply_sync(lambda : 1)
         self.assertEqual(r, [1] * n1)
-        
+
         # map goes through remotefunction
         r = v.map_sync(double, seq)
         self.assertEqual(r, ref)
@@ -109,22 +112,22 @@ class TestClient(ClusterTestCase):
         self.add_engines(2)
         n2 = len(self.client.ids)
         self.assertNotEqual(n2, n1)
-        
+
         # apply
         r = v.apply_sync(lambda : 1)
         self.assertEqual(r, [1] * n2)
-        
+
         # map
         r = v.map_sync(double, seq)
         self.assertEqual(r, ref)
-    
+
     def test_targets(self):
         """test various valid targets arguments"""
         build = self.client._build_targets
         ids = self.client.ids
         idents,targets = build(None)
         self.assertEqual(ids, targets)
-    
+
     def test_clear(self):
         """test clear behavior"""
         self.minimum_engines(2)
@@ -139,7 +142,7 @@ class TestClient(ClusterTestCase):
         self.client.clear(block=True)
         for i in self.client.ids:
             self.assertRaisesRemote(NameError, self.client[i].get, 'a')
-    
+
     def test_get_result(self):
         """test getting results from the Hub."""
         c = clientmod.Client(profile='iptest')
@@ -158,7 +161,7 @@ class TestClient(ClusterTestCase):
         ar3 = self.client.get_result([ar2])
         self.assertEqual(ar3.msg_ids, ar2.msg_ids)
         c.close()
-    
+
     def test_get_execute_result(self):
         """test getting execute results from the Hub."""
         c = clientmod.Client(profile='iptest')
@@ -178,7 +181,7 @@ class TestClient(ClusterTestCase):
         self.assertNotIsInstance(ar2, AsyncHubResult)
         self.assertEqual(ahr.get(), ar2.get())
         c.close()
-    
+
     def test_ids_list(self):
         """test client.ids"""
         ids = self.client.ids
@@ -186,7 +189,7 @@ class TestClient(ClusterTestCase):
         self.assertFalse(ids is self.client._ids)
         ids.remove(ids[-1])
         self.assertNotEqual(ids, self.client._ids)
-    
+
     def test_queue_status(self):
         ids = self.client.ids
         id0 = ids[0]
@@ -212,9 +215,9 @@ class TestClient(ClusterTestCase):
         ids = self.client.ids
         id0 = ids[-1]
         pid = self.client[id0].apply_sync(os.getpid)
-        
+
         self.client.shutdown(id0, block=True)
-        
+
         for i in range(150):
             # give the engine 15 seconds to die
             if id0 not in self.client.ids:
@@ -222,11 +225,11 @@ class TestClient(ClusterTestCase):
             time.sleep(0.1)
         self.assertNotIn(id0, self.client.ids)
         self.assertRaises(IndexError, lambda : self.client[id0])
-    
+
     def test_result_status(self):
         pass
         # to be written
-    
+
     def test_db_query_dt(self):
         """test db query by date"""
         hist = self.client.hub_history()
@@ -242,13 +245,13 @@ class TestClient(ClusterTestCase):
         same = self.client.db_query({'submitted' : tic})
         for s in same:
             self.assertTrue(s['submitted'] == tic)
-    
+
     def test_db_query_keys(self):
         """test extracting subset of record keys"""
         found = self.client.db_query({'msg_id': {'$ne' : ''}},keys=['submitted', 'completed'])
         for rec in found:
             self.assertEqual(set(rec.keys()), set(['msg_id', 'submitted', 'completed']))
-    
+
     def test_db_query_default_keys(self):
         """default db_query excludes buffers"""
         found = self.client.db_query({'msg_id': {'$ne' : ''}})
@@ -256,7 +259,7 @@ class TestClient(ClusterTestCase):
             keys = set(rec.keys())
             self.assertFalse('buffers' in keys, "'buffers' should not be in: %s" % keys)
             self.assertFalse('result_buffers' in keys, "'result_buffers' should not be in: %s" % keys)
-    
+
     def test_db_query_msg_id(self):
         """ensure msg_id is always in db queries"""
         found = self.client.db_query({'msg_id': {'$ne' : ''}},keys=['submitted', 'completed'])
@@ -268,7 +271,7 @@ class TestClient(ClusterTestCase):
         found = self.client.db_query({'msg_id': {'$ne' : ''}},keys=['msg_id'])
         for rec in found:
             self.assertTrue('msg_id' in rec.keys())
-    
+
     def test_db_query_get_result(self):
         """pop in db_query shouldn't pop from result itself"""
         self.client[:].apply_sync(lambda : 1)
@@ -280,7 +283,7 @@ class TestClient(ClusterTestCase):
         self.assertTrue(ar.ready())
         ar.get()
         rc2.close()
-    
+
     def test_db_query_in(self):
         """test db query with '$in','$nin' operators"""
         hist = self.client.hub_history()
@@ -292,14 +295,14 @@ class TestClient(ClusterTestCase):
         recs = self.client.db_query({ 'msg_id' : {'$nin' : even}})
         found = [ r['msg_id'] for r in recs ]
         self.assertEqual(set(odd), set(found))
-    
+
     def test_hub_history(self):
         hist = self.client.hub_history()
         recs = self.client.db_query({ 'msg_id' : {"$ne":''}})
         recdict = {}
         for rec in recs:
             recdict[rec['msg_id']] = rec
-        
+
         latest = datetime(1984,1,1).replace(tzinfo=utc)
         for msg_id in hist:
             rec = recdict[msg_id]
@@ -310,15 +313,15 @@ class TestClient(ClusterTestCase):
         ar.get()
         time.sleep(0.25)
         self.assertEqual(self.client.hub_history()[-1:],ar.msg_ids)
-    
+
     def _wait_for_idle(self):
         """wait for the cluster to become idle, according to the everyone."""
         rc = self.client
-        
+
         # step 0. wait for local results
         # this should be sufficient 99% of the time.
         rc.wait(timeout=5)
-        
+
         # step 1. wait for all requests to be noticed
         # timeout 5s, polling every 100ms
         msg_ids = set(rc.history)
@@ -329,9 +332,9 @@ class TestClient(ClusterTestCase):
                 hub_hist = rc.hub_history()
             else:
                 break
-        
+
         self.assertEqual(len(msg_ids.difference(hub_hist)), 0)
-        
+
         # step 2. wait for all requests to be done
         # timeout 5s, polling every 100ms
         qs = rc.queue_status()
@@ -341,14 +344,14 @@ class TestClient(ClusterTestCase):
                 qs = rc.queue_status()
             else:
                 break
-        
+
         # ensure Hub up to date:
         self.assertEqual(qs['unassigned'], 0)
         for eid in [ eid for eid in qs if eid != 'unassigned' ]:
             self.assertEqual(qs[eid]['tasks'], 0)
             self.assertEqual(qs[eid]['queue'], 0)
-    
-    
+
+
     def test_resubmit(self):
         def f():
             import random
@@ -369,11 +372,11 @@ class TestClient(ClusterTestCase):
         ar.get()
         self._wait_for_idle()
         ars = [ar]
-        
+
         for i in range(10):
             ar = ars[-1]
             ar2 = self.client.resubmit(ar.msg_ids)
-        
+
         [ ar.get() for ar in ars ]
 
     def test_resubmit_header(self):
@@ -458,7 +461,7 @@ class TestClient(ClusterTestCase):
         self.client.purge_local_results(msg_id)
         self.assertLessEqual(len(self.client.results), before-1, msg="Not removed from results")
         self.assertLessEqual(len(self.client.metadata), before-1, msg="Not removed from metadata")
-    
+
     def test_purge_local_results_outstanding(self):
         v = self.client[-1]
         ar = v.apply_async(time.sleep, 1)
@@ -466,7 +469,7 @@ class TestClient(ClusterTestCase):
             self.client.purge_local_results(ar)
         ar.get()
         self.client.purge_local_results(ar)
-    
+
     def test_purge_all_local_results_outstanding(self):
         v = self.client[-1]
         ar = v.apply_async(time.sleep, 1)
@@ -474,7 +477,7 @@ class TestClient(ClusterTestCase):
             self.client.purge_local_results('all')
         ar.get()
         self.client.purge_local_results('all')
-    
+
     def test_purge_all_hub_results(self):
         self.client.purge_hub_results('all')
         hist = self.client.hub_history()
@@ -496,7 +499,7 @@ class TestClient(ClusterTestCase):
         self.assertEqual(len(self.client.metadata), 0, msg="metadata not empty")
         hist = self.client.hub_history()
         self.assertEqual(len(hist), 0, msg="hub history not empty")
-        
+
     def test_purge_everything(self):
         # ensure there are some tasks
         for i in range(5):
@@ -533,7 +536,7 @@ class TestClient(ClusterTestCase):
         self.assertTrue('pxall' in magics['line'])
         self.assertTrue('pxall' in magics['cell'])
         self.assertEqual(v0.targets, 'all')
-    
+
     def test_wait_interactive(self):
         ar = self.client[-1].apply_async(lambda : 1)
         self.client.wait_interactive()
@@ -553,6 +556,9 @@ class TestClient(ClusterTestCase):
     @pytest.mark.skipif(
         sys.version_info[:2] == (3, 4),
         reason="become_dask doesn't work on Python 3.4")
+    @pytest.mark.skipif(
+        tornado.version_info[:2] < (5,),
+        reason="become_dask doesn't work with tornado 4")
     def test_become_dask(self):
         executor = self.client.become_dask()
         reprs = self.client[:].apply_sync(repr, Reference('distributed_worker'))
@@ -564,8 +570,28 @@ class TestClient(ClusterTestCase):
         self.assertEqual(tot.result(), 285)
 
         # cleanup
-        executor.shutdown()
+        executor.close()
         self.client.stop_dask()
         ar = self.client[:].apply_async(lambda x: x, Reference('distributed_worker'))
         self.assertRaisesRemote(NameError, ar.get)
 
+    def test_warning_on_hostname_match(self):
+        location = socket.gethostname()
+        with mock.patch('ipyparallel.client.client.is_local_ip',
+                        lambda x: False):
+            with mock.patch('socket.gethostname', lambda: location[0:-1]), \
+                 pytest.warns(RuntimeWarning): # should trigger warning
+                c = self.connect_client()
+                c.close()
+            with mock.patch('socket.gethostname', lambda: location), \
+                    pytest.warns(None) as record:  # should not trigger warning
+                c = self.connect_client()
+                assert len(record) == 0, str(record)
+                c.close()
+
+    def test_local_ip_true_doesnt_trigger_warning(self):
+        with mock.patch('ipyparallel.client.client.is_local_ip',
+                        lambda x: True), pytest.warns(None) as record:
+            c = self.connect_client()
+            assert len(record) == 0, str(record)
+            c.close()
